:root {
    --cookie-consent-wrapper-bg: rgba(0,0,0,.5);
    --cookie-consent-bg: #fafafa;
    --cookie-consent-text-color: #333;
    --cookie-consent-text-color-disabled: #555;
    --cookie-modal-checkbox-color: 13, 181, 66;
    --cookie-consent-border: 1px solid #ddd;
}

.ga-cookie-modal .form-group {
    display: flex;
    flex-direction: column;
    margin-bottom: 0.5em;
}
.ga-cookie-modal .form-group p {
    margin: 0;
    padding: 0;
    font-size: 0.8em;
    color: var(--cookie-consent-text-color);
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) input[type="checkbox"] {
  display: none;
  visibility: hidden;
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) label {
  position: relative;
  padding-left: 2em;
  padding-right: 1em;
  line-height: 2;
  cursor: pointer;
  display: inline-flex;
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) label:before {
  box-sizing: border-box;
  content: " ";
  position: absolute;
  top: 0.3em;
  left: 0;
  display: block;
  width: 1.4em;
  height: 1.4em;
  border: 2px solid var(--cookie-consent-text-color);
  border-radius: 6px;
  z-index: 1;
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) span.label-text {
    z-index: 10;
    color: var(--cookie-consent-text-color);
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) .form-help-text {
    margin-top: 0.3em;
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) input[type=checkbox]:checked + label{
  padding-left: 1em;
  color: rgb(var(--cookie-modal-checkbox-color));
}
.ga-cookie-modal .form-group:has(input[type="checkbox"]) input[type=checkbox]:checked + label .label-text {
  color: rgb(var(--cookie-modal-checkbox-color));
}
.ga-cookie-modal .form-group:has(input[type="checkbox"]) input[type=checkbox]:checked + label:before {
  top: 0;
  width: 100%;
  height: 100%;
  background: rgba(var(--cookie-modal-checkbox-color), 0.3);
  border-color: rgba(var(--cookie-modal-checkbox-color), 0.3);
}

.ga-cookie-modal .form-group:has(input[type="checkbox"]) label,
.ga-cookie-modal .form-group:has(input[type="checkbox"]) label::before {
  transition: 0.25s all ease;
}
  
  
.ga-cookie-modal .form-group input:not([type="checkbox"]),
.ga-cookie-modal .form-group textarea,
.ga-cookie-modal .form-group select {
    width: 100%;
    height: inherit;
    padding: 0.5em;
    border-radius: 5px;
    border: var(--cookie-consent-border);
    background-color: var(--cookie-consent-bg);
    color: var(--cookie-consent-text-color);
    transition: all 0.2s ease-in-out;
}

.ga-cookie-modal .form-group input:focus,
.ga-cookie-modal .form-group textarea:focus,
.ga-cookie-modal .form-group select:focus {
    outline: none;
    border: 1px solid var(--cookie-consent-border);
}
.ga-cookie-modal .form-field {
    width: 100%;
}


.ga-cookie-modal-wrapper {
    position: fixed;
    z-index: 9999;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    background-color: var(--cookie-consent-wrapper-bg);
}
.ga-cookie-modal {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    width: 90%;
    max-width: 600px;
    border-radius: 5px;
    background-color: var(--cookie-consent-bg);
    color: var(--cookie-consent-text-color);
    border: var(--cookie-consent-border);
    box-shadow: 0 0 10px var(--cookie-consent-wrapper-bg);
}
.ga-cookie-modal-tabs {
    display: flex;
    flex-direction: column;
    height: 100%;
}
.ga-cookie-modal-tab {
    display: none;
    flex: 1;
    overflow: hidden;
}
.ga-cookie-modal-tab.open {
    display: block;
}
.ga-cookie-modal-header {
    padding: 20px;
    border-bottom: var(--cookie-consent-border);
}
.ga-cookie-modal-title {
    margin: 0;
    font-weight: 600;
    font-size: 1.5em;
}
.ga-cookie-modal-content {
    padding: 20px;
    overflow-y: auto;
    border-bottom: var(--cookie-consent-border);
}

.ga-cookie-modal-title {
    display: flex;
    align-items: center;
    justify-content: space-between;
}
.ga-cookie-modal-title .icon {
    height: 45px;
    object-fit: contain;
}