{% extends extends_from %}

{% load i18n %}

{% block content %}

    <div class="row">
        <div class="col-12 mb-1">
            <h1>{% translate "Cookie Policy/Statement" %}</h1>
        </div>

        {% for panel in panels %}

            <div class="col-12 col-xs-12 col-sm-12 col-md-12 col-lg-6 col-xl-6 mb-1">
                <div class="cookie-consent-panel-title">
                    <h3>{{panel.title}}</h3>
                </div>
                <div class="cookie-consent-panel-body">
                    <p>{{panel.long_description}}</p>
                </div>
            </div>

        {% endfor %}

        {% for panel in extra_panels %}
            <div class="col-12 mb-1">
                <div class="cookie-consent-panel-title">
                    <h3>{{panel.title}}</h3>
                </div>
                <div class="cookie-consent-panel-body">
                    <p>{{panel.description}}</p>
                </div>
            </div>
        {% endfor %}

        {% if request.cookie_consent.submitted %}
            <div class="col-12">
                <!--In accordance to EU guidelines.-->
                <div class="cookie-policy-revoke">
                    <a href="{{cookie_modal_policy_url}}" class="link">{% translate "Revoke Cookie Consent" %}</a>
                </div>
            </div>
        {% endif %}

    </div>


{% endblock %}